@@ -8,6 +8,11 @@ NULL
 ## usethis namespace: end
 NULL
 
+## usethis namespace: start
+#' @importFrom grDevices palette
+## usethis namespace: end
+NULL
+
 ## usethis namespace: start
 #' @importFrom stats na.omit
 ## usethis namespace: end
@@ -18,6 +23,11 @@ NULL
 ## usethis namespace: end
 NULL
 
+## usethis namespace: start
+#' @importFrom lattice dotplot
+## usethis namespace: end
+NULL
+
 ## usethis namespace: start
 #' @importFrom lattice histogram
 ## usethis namespace: end
@@ -32,3 +42,14 @@ NULL
 #' @importFrom lattice panel.histogram
 ## usethis namespace: end
 NULL
+
+## usethis namespace: start
+#' @importFrom lattice panel.abline
+## usethis namespace: end
+NULL
+
+
+## usethis namespace: start
+#' @importFrom graphics mosaicplot
+## usethis namespace: end
+NULL
